{% load i18n pages_tags %}

<ul>
	{% for page in page_branch %}
	{% if not page.parent_id and forloop.first %}
	<li><a href="{% url home %}">{% trans "Home" %}</a></li>
	{% endif %}
	<li>
		<a href="{% url page page.slug %}">{{ page.title }}</a>
		{# remove this if tag to always show all nav items #}
		{% if PAGES_MENU_SHOW_ALL or page.selected %}
		{% page_menu page %}
		{% endif %}
	</li>
	{% endfor %}
</ul>

