{% load pages_tags mezzanine_tags %}
<html>

<head>

    <meta http-equiv="Content-type" content="text/html; charset=utf-8" /> 
	<meta name="keywords" content="{% block keywords %}{% endblock %}" /> 
	<meta name="description" content="{% block description %}{% endblock %}" /> 
    <title>{% block meta_title %}{% endblock %}</title>
    <link rel="alternate" type="application/rss+xml" title="RSS" 
        href="{% url blog_post_feed "rss" %}" />
    <link rel="alternate" type="application/atom+xml" title="Atom"  
        href="{% url blog_post_feed "atom" %}" />

    <style type="text/css">

        * {margin:0; padding:0; font-family:Garamond,Georgia,serif;}
        h1, h2 {margin:20px 0; font-weight:normal;}
        h1 {font-size:250%; border-bottom:1px solid #ccc; padding-bottom:20px;}
        #menu, #main, #right-panel {float:left; height:100%;}
        #menu, #right-panel {background:#e9e9e9;}
        #menu {padding:50px; font-size:130%;}
        #main {padding:0 30px; width:400px;}
        #right-panel {padding:8px 30px;}
        a {color:#008;}
        
        ul {list-style-type:none;}
        #menu ul ul {padding-left:30px; list-style-type:disc; font-size:80%;}
        #menu ul ul li {margin:5px auto;}
        #blog-description {margin:30px 0;}
        .paging {margin-top:30px; padding-top:10px; border-top:1px solid #ccc;}
        .paging * {display:inline; margin-right:3px;}
        em {display:block; font-size:80%; margin-bottom:10px;}

        #comments {margin-top:20px;}
        #comments img {margin-right:5px; vertical-align:middle;}
        #comments em {margin-bottom:0;}
        #comments p {border-bottom:1px solid #ddd; padding:5px 0;
            margin-bottom:5px;}
        .description {margin-bottom:20px;}
        .share {margin:20px 0; background:#eee; padding:10px;}
        #comments ul {margin:20 0; padding:0;}
        #comments li ul {padding-left:30px;}
        .comment {background:#eee; padding:20px; margin-top:20px;}
        .comment th, .comment td {text-align:left; vertical-align:top; 
            padding:2px 5px;}
        .comment .button {float:right; padding:10px; margin:10px 0; 
            cursor:pointer;}
        input, textarea {border:1px solid #999;}
        ul .comment {display:none;}
        ul .posted {display:block !important;}
        .errorlist {color:#f00; margin:0 !important; padding:0 !important;}
        
        .tags {margin:10px 0;}
        .tags ul, .tags li {display:inline;}
        .tag-weight-1 {font-size:80%;}
        .tag-weight-2 {font-size:120%;}
        .tag-weight-3 {font-size:160%;}
        .tag-weight-4 {font-size:200%;}
        
        .tweets li {font-size:70%; width:190px; clear:both; margin-bottom:10px;}
        .tweets img {float:left; border:1px solid #000; margin:0 5px 5px 0;
            width:32px; height:32px;}
        .tweets .timespan {font-style:italic; display:block;}
        .recycle {font-size:150%;}
        .retweet  {float:none; margin-bottom:-5px; width:16px; height:16px;}
        .mezzanine {margin-top:30px; font-size:80%; text-align:center;}

    </style>

    {% block extra_head %}{% endblock %}

</head>

<body>
    <div id="menu">
        {% page_menu %}
    </div>
    <div id="main">
        <h1>{% block title %}{% endblock %}</h1>
        {% block main %}{% endblock %}
    </div>
    <div id="right-panel">
        {% block right_panel %}
        {% include "twitter/tweets.html" %}
        {% endblock %}
        <p class="mezzanine">Powered by <a 
            href="http://github.com/stephenmcd/mezzanine">Mezzanine</a></p>
    </div>
    <script type="text/javascript">
        var gaID = '{% setting "GOOGLE_ANALYTICS_ID" %}';
        if (gaID) {
            var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
            document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
        }
    </script>
    <script type="text/javascript">
        if (gaID) {
            var pageTracker = _gat._getTracker(gaID);
            pageTracker._trackPageview();
        }
    </script>
</body>

</html>

