{% extends "admin/change_form.html" %}

{% block extrahead %}
{{ block.super }}
<style>
	.form-row li {list-style-type:none !important; float:left; margin-right:10px;}
	.form-row li label {width:auto !important;}
</style>
{% endblock %}
