{% load i18n blog_tags %}

<ul style="margin:0;">
    {% for comment in comments %}
    <li style="padding:10px; list-style-type:none; 
        background:#{% cycle "fff" "f7f7f7" %};">    
        <a href="mailto:{{ comment.email }}"><img 
            src="{% gravatar_url comment.email_hash %}"
            style="margin:-2px 8px 0 0; float:left; border:1px solid #666;"
            />{{ comment.name }}</a><br />
        <span class="mini quiet">
            {{ comment.time_created|timesince }} {% trans "ago" %}<br />
            {{ comment.body|truncatewords:"40" }}<br />
            {% if comment.blog_post %}
            {% url blog_post_detail comment.blog_post.slug as blog_post_url %}
            {% trans "Posted to" %}: <a 
                href="{{ blog_post_url }}#comment-{{ comment.id }}"
                >{{ comment.blog_post.title }}</a>
             / <a href="{{ blog_post_url }}">{% trans "View comment" %}</a>
            {% endif %}
        </span>
    </li>
    {% endfor %}
</ul>
