{% load i18n blog_tags %}

<h2>{% trans "Comments" %}</h2>
{% blog_comments_for blog_post %}
<form method="post" class="comment" id="comment" action="#comment">
    <table>
    {% if request.POST.replied_to %}
    {{ unposted_comment_form.as_table }}
    {% else %}
    {{ posted_comment_form.as_table }}
    {% endif %}
    <tr><td colspan="2">
    <input class="button" type="submit" value="{% trans "Comment" %}" />
    </td></tr>
    </table>
</form>

